#!/bin/sh
# ---------------------------------------------------------------------
# Licensed Materials - Property of IBM
#
# Copyright IBM Corporation 2016, 2017. All Rights Reserved.
#
# US Government Users Restricted Rights- Use, duplication or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corp. 
# ---------------------------------------------------------------------
# ftmip_config.sh
# Populates the FTM Database with the FTM IP Configuration (Unix Version)
# ---------------------------------------------------------------------


if [ -z "$2" ]
then
	echo "Syntax: ftmip_config.sh [Database Name] [Database Schema]"
else

# Work with a copy of the file to make the parameter marker changes. 
cp config.sql temp_config.sql

# Read in the properties for use in the parameter markers:
filename=$(basename "$0")
filename="${filename%.*}"

oIFS="$IFS";
IFS='='  
(cat $filename.properties; echo;) | while read -r key value
do
  perl -i -pe 's/\+\+'$key'\+\+/'$value'/g;' temp_config.sql  
done
IFS="$oIFS"

	DB_NAME=$1
	DB_SCHEMA=$2

    echo Connecting to the database... 	
	db2 connect to $DB_NAME

    echo Setting the current schema...
	db2 set current schema $DB_SCHEMA

    echo Setting the current path...
	db2 set current path $DB_SCHEMA

    echo Processing the Configuration data...
	db2 -tvf temp_config.sql

    echo Processing the FSM data...
	db2 -tvf fsm.sql

    echo Processing Resource permissions...
	db2 -tvf resource_permissions.sql

    echo Processing Group permissions...
	db2 -tvf group_permissions.sql 	

#   echo Processing development settings...
#   db2 -tvf dev_config.sql

#   echo Defining custom queries...
#	db2 -tvf custom_queries.sql 	
	
    echo Disconnecting from the database...
	db2 connect reset

fi

# *
# * End!
# *
